searchData={"items":[{"type":"module","title":"Pigeon","doc":"HTTP2-compliant wrapper for sending iOS and Android push notifications.","ref":"Pigeon.html"},{"type":"module","title":"Getting Started - Pigeon","doc":"Check the module documentation for your push notification service.\n\n  - `Pigeon.ADM` - Amazon Android.\n  - `Pigeon.APNS` - Apple iOS.\n  - `Pigeon.FCM` - Firebase Cloud Messaging v1 API.\n  - `Pigeon.LegacyFCM` - Firebase Cloud Messaging Legacy API.","ref":"Pigeon.html#module-getting-started"},{"type":"module","title":"Creating Dynamic Runtime Dispatchers - Pigeon","doc":"Pigeon can spin up dynamic dispatchers for a variety of advanced use-cases, such as\nsupporting dozens of dispatcher configurations or custom connection pools.\n\nSee `Pigeon.Dispatcher` for instructions.","ref":"Pigeon.html#module-creating-dynamic-runtime-dispatchers"},{"type":"module","title":"Writing a Custom Dispatcher Adapter - Pigeon","doc":"Want to write a Pigeon adapter for an unsupported push notification service?\n\nSee `Pigeon.Adapter` for instructions.","ref":"Pigeon.html#module-writing-a-custom-dispatcher-adapter"},{"type":"function","title":"Pigeon.default_pool_size/0","doc":"Returns the configured default pool size for Pigeon dispatchers.\nTo customize this value, include the following in your config/config.exs:\n\n    config :pigeon, :default_pool_size, 5","ref":"Pigeon.html#default_pool_size/0"},{"type":"function","title":"Pigeon.json_library/0","doc":"Returns the configured JSON encoding library for Pigeon.\nTo customize the JSON library, include the following in your config/config.exs:\n\n    config :pigeon, :json_library, Jason","ref":"Pigeon.html#json_library/0"},{"type":"function","title":"Pigeon.push/3","doc":"","ref":"Pigeon.html#push/3"},{"type":"type","title":"Pigeon.notification/0","doc":"","ref":"Pigeon.html#t:notification/0"},{"type":"type","title":"Pigeon.on_response/0","doc":"Async callback for push notifications response.","ref":"Pigeon.html#t:on_response/0"},{"type":"type","title":"Examples - Pigeon.on_response/0","doc":"handler = fn(%Pigeon.ADM.Notification{response: response}) ->\n      case response do\n        :success ->\n          Logger.debug \"Push successful!\"\n        :unregistered ->\n          Logger.error \"Bad device token!\"\n        _error ->\n          Logger.error \"Some other error happened.\"\n      end\n    end\n\n    n = Pigeon.ADM.Notification.new(\"token\", %{\"message\" => \"test\"})\n    Pigeon.ADM.push(n, on_response: handler)","ref":"Pigeon.html#t:on_response/0-examples"},{"type":"type","title":"Pigeon.push_opts/0","doc":"Options for sending push notifications.\n\n- `:on_response` - Optional async callback triggered on receipt of push.\n  See `t:on_response/0`\n- `:timeout` - Push timeout. Defaults to 5000ms.","ref":"Pigeon.html#t:push_opts/0"},{"type":"behaviour","title":"Pigeon.Adapter","doc":"Adapter behaviour for `Pigeon.Dispatcher` push workers.\n\n`Pigeon.Adapter` closely resembles `GenServer` behaviour, as dispatchers\nare GenServers under the hood.","ref":"Pigeon.Adapter.html"},{"type":"behaviour","title":"Example Adapter - Pigeon.Adapter","doc":"```\ndefmodule Pigeon.Sandbox do\n  import Pigeon.Tasks, only: [process_on_response: 1]\n\n  @behaviour Pigeon.Adapter\n\n  @impl true\n  def init(opts \\ []) do\n    {:ok, opts}\n  end\n\n  @impl true\n  def handle_info(_msg, state) do\n    {:noreply, state}\n  end\n\n  @impl true\n  def handle_push(%{response: nil} = notification, state) do\n    process_on_response(%{notification | response: :success})\n    {:noreply, state}\n  end\n\n  def handle_push(notification, state) do\n    process_on_response(notification)\n    {:noreply, state}\n  end\nend\n```","ref":"Pigeon.Adapter.html#module-example-adapter"},{"type":"callback","title":"Pigeon.Adapter.handle_info/2","doc":"Invoked to handle all other messages.","ref":"Pigeon.Adapter.html#c:handle_info/2"},{"type":"callback","title":"Pigeon.Adapter.handle_push/2","doc":"Invoked to handle push notifications.","ref":"Pigeon.Adapter.html#c:handle_push/2"},{"type":"callback","title":"Pigeon.Adapter.init/1","doc":"Invoked when the server is started.\n\nReturn value should be `{:ok, state}` for the `Pigeon.Dispatcher` state,\nor `{:stop, atom}` if started with invalid configuration options.","ref":"Pigeon.Adapter.html#c:init/1"},{"type":"module","title":"Pigeon.Dispatcher","doc":"Dispatcher worker for push notifications.\n\nIf your push workers are relatively static, it is encouraged to follow the adapter\nguides. For other use cases, such as supporting dynamic configurations, dispatchers\ncan be started and stopped as needed.","ref":"Pigeon.Dispatcher.html"},{"type":"module","title":"Using Dynamic Dispatchers - Pigeon.Dispatcher","doc":"```\n# FCM as an example, but use the relevant options for your push type.\nopts = [\n  adapter: Pigeon.FCM,\n  project_id: \"example-project-123\",\n  service_account_json: File.read!(\"service-account.json\")\n]\n\n{:ok, pid} = Pigeon.Dispatcher.start_link(opts)\nnotification = Pigeon.FCM.Notification.new({:token, \"regid\"})\n\nPigeon.push(pid, notification)\n```","ref":"Pigeon.Dispatcher.html#module-using-dynamic-dispatchers"},{"type":"module","title":"Loading Configurations from a Database - Pigeon.Dispatcher","doc":"```\ndefmodule YourApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @doc false\n  def start(_type, _args) do\n    children = [\n      YourApp.Repo,\n      {Registry, keys: :unique, name: Registry.YourApp}\n    ] ++ push_workers()\n    opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n\n  defp push_workers do\n    YourApp.Repo.PushApplication\n    |> YourApp.Repo.all()\n    |> Enum.map(&push_spec/1)\n  end\n\n  defp push_spec(%{type: \"apns\"} = config)\n    {Pigeon.Dispatcher, [\n      adapter: Pigeon.APNS,\n      key: config.key,\n      key_identifier: config.key_identifier,\n      team_id: config.team_id,\n      mode: config.mode,\n      name: {:via, Registry, {Registry.YourApp, config.name}}\n    ]}\n  end\n\n  defp push_spec(%{type: \"fcm\"} = config) do\n    {Pigeon.Dispatcher, [\n      adapter: Pigeon.FCM,\n      name: {:via, Registry, {Registry.YourApp, config.name}},\n      project_id: config.project_id,\n      service_account_json: config.service_account_json\n    ]}\n  end\nend\n```\n\nOnce running, you can send to any of these workers by name.\n\n```\nPigeon.push({:via, Registry, {Registry.YourApp, \"app1\"}}, notification)\n```","ref":"Pigeon.Dispatcher.html#module-loading-configurations-from-a-database"},{"type":"function","title":"Pigeon.Dispatcher.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Pigeon.Dispatcher.html#child_spec/1"},{"type":"function","title":"Pigeon.Dispatcher.init/1","doc":"","ref":"Pigeon.Dispatcher.html#init/1"},{"type":"function","title":"Pigeon.Dispatcher.start_link/1","doc":"","ref":"Pigeon.Dispatcher.html#start_link/1"},{"type":"module","title":"Pigeon.Metadata","doc":"Internal push notification metadata.","ref":"Pigeon.Metadata.html"},{"type":"type","title":"Pigeon.Metadata.t/0","doc":"","ref":"Pigeon.Metadata.html#t:t/0"},{"type":"module","title":"Pigeon.Sandbox","doc":"Sandbox adapter for any kind of push notification.\n\nIf the push notification has `response: nil`, it will be marked\nwith `response: :success`. Otherwise it will return the push notification\nexactly as given.","ref":"Pigeon.Sandbox.html"},{"type":"module","title":"Pigeon.ADM","doc":"`Pigeon.Adapter` for ADM (Amazon Android) push notifications.","ref":"Pigeon.ADM.html"},{"type":"module","title":"Getting Started - Pigeon.ADM","doc":"1. Create an ADM dispatcher.\n\n```\n# lib/adm.ex\ndefmodule YourApp.ADM do\n  use Pigeon.Dispatcher, otp_app: :your_app\nend\n```\n\n2. (Optional) Add configuration to your `config.exs`.\n\n```\n# config.exs\n\nconfig :your_app, YourApp.ADM,\n  adapter: Pigeon.ADM,\n  client_id: \"your_oauth2_client_id_here\",\n  client_secret: \"your_oauth2_client_secret_here\"\n```\n\n3. Start your dispatcher on application boot.\n\n```\ndefmodule YourApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @doc false\n  def start(_type, _args) do\n    children = [\n      YourApp.ADM\n    ]\n    opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nIf you skipped step two, include your configuration.\n\n```\ndefmodule YourApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @doc false\n  def start(_type, _args) do\n    children = [\n      {YourApp.ADM, adm_opts()}\n    ]\n    opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n\n  defp adm_opts do\n    [\n      adapter: Pigeon.ADM, \n      client_id: \"client_id\", \n      client_secret: \"secret\"\n    ]\n  end\nend\n```\n\n4. Create a notification.\n\n```\nmsg = %{ \"body\" => \"your message\" }\nn = Pigeon.ADM.Notification.new(\"your device registration ID\", msg)\n```\n\n5. Send the notification.\n\n```\nYourApp.ADM.push(n)\n```","ref":"Pigeon.ADM.html#module-getting-started"},{"type":"module","title":"Handling Push Responses - Pigeon.ADM","doc":"1. Pass an optional anonymous function as your second parameter.\n\n```\ndata = %{ message: \"your message\" }\nn = Pigeon.ADM.Notification.new(\"device registration ID\", data)\nYourApp.ADM.push(n, on_response: fn(x) -> IO.inspect(x) end)\n```\n\n2. Responses return a notification with an updated `:response` key.\n   You could handle responses like so:\n\n```\non_response_handler = fn(x) ->\n  case x.response do\n    :success ->\n      # Push successful\n      :ok\n    :update ->\n      new_reg_id = x.updated_registration_id\n      # Update the registration ID in the database\n    :invalid_registration_id ->\n      # Remove the bad ID from the database\n    :unregistered ->\n      # Remove the bad ID from the database\n    error ->\n      # Handle other errors\n  end\nend\n\ndata = %{ message: \"your message\" }\nn = Pigeon.ADM.Notification.new(\"your registration id\", data)\nPigeon.ADM.push(n, on_response: on_response_handler)\n```","ref":"Pigeon.ADM.html#module-handling-push-responses"},{"type":"module","title":"Error Responses - Pigeon.ADM","doc":"*Taken from [Amazon Device Messaging docs](https://developer.amazon.com/public/apis/engage/device-messaging/tech-docs/06-sending-a-message)*\n\n| Reason                           | Description                      |\n|----------------------------------|----------------------------------|\n| `:invalid_registration_id`       | Invalid Registration Token       |\n| `:invalid_data`                  | Bad format JSON data             |\n| `:invalid_consolidation_key`     | Invalid Consolidation Key        |\n| `:invalid_expiration`            | Invalid expiresAfter value       |\n| `:invalid_checksum`              | Invalid md5 value                |\n| `:invalid_type`                  | Invalid Type header              |\n| `:unregistered`                  | App instance no longer available |\n| `:access_token_expired`          | Expired OAuth access token       |\n| `:message_too_large`             | Data size exceeds 6 KB           |\n| `:max_rate_exceeded`             | See Retry-After response header  |\n| `:unknown_error`                 | Unknown Error                    |","ref":"Pigeon.ADM.html#module-error-responses"},{"type":"module","title":"Pigeon.ADM.Notification","doc":"Defines Amazon ADM notification struct and convenience constructor functions.","ref":"Pigeon.ADM.Notification.html"},{"type":"function","title":"Pigeon.ADM.Notification.new/2","doc":"Creates `ADM.Notification` struct with device registration ID and optional data payload.","ref":"Pigeon.ADM.Notification.html#new/2"},{"type":"function","title":"Examples - Pigeon.ADM.Notification.new/2","doc":"iex> Pigeon.ADM.Notification.new(\"reg ID\")\n    %Pigeon.ADM.Notification{\n      consolidation_key: nil,\n      md5: \"1B2M2Y8AsgTpgAmY7PhCfg==\",\n      payload: %{\"data\" => %{}},\n      registration_id: \"reg ID\",\n      updated_registration_id: nil\n    }\n\n    iex> Pigeon.ADM.Notification.new(\"reg ID\", %{\"message\" => \"your message\"})\n    %Pigeon.ADM.Notification{\n      consolidation_key: nil,\n      md5: \"qzF+HgArKZjJrpfcTbiFxg==\",\n      payload: %{\n        \"data\" => %{\"message\" => \"your message\"}\n      },\n      registration_id: \"reg ID\",\n      updated_registration_id: nil\n    }\n\n    iex> Pigeon.ADM.Notification.new(\"reg ID\", \"not a map\")\n    %Pigeon.ADM.Notification{\n      consolidation_key: nil,\n      md5: \"1B2M2Y8AsgTpgAmY7PhCfg==\",\n      payload: %{\"data\" => %{}},\n      registration_id: \"reg ID\",\n      updated_registration_id: nil\n    }","ref":"Pigeon.ADM.Notification.html#new/2-examples"},{"type":"function","title":"Pigeon.ADM.Notification.put_data/2","doc":"Updates `\"data\"` key on push payload and calculates `md5` hash.","ref":"Pigeon.ADM.Notification.html#put_data/2"},{"type":"function","title":"Examples - Pigeon.ADM.Notification.put_data/2","doc":"iex> n = %Pigeon.ADM.Notification{}\n    iex> Pigeon.ADM.Notification.put_data(n, %{\"message\" => \"your message\"})\n    %Pigeon.ADM.Notification{\n      consolidation_key: nil,\n      md5: \"qzF+HgArKZjJrpfcTbiFxg==\",\n      payload: %{\n        \"data\" => %{\"message\" => \"your message\"}\n      },\n      registration_id: nil,\n      updated_registration_id: nil\n    }","ref":"Pigeon.ADM.Notification.html#put_data/2-examples"},{"type":"type","title":"Pigeon.ADM.Notification.error_response/0","doc":"ADM error responses","ref":"Pigeon.ADM.Notification.html#t:error_response/0"},{"type":"type","title":"Pigeon.ADM.Notification.response/0","doc":"ADM push response\n\n- nil - Push has not been sent yet\n- `:success` - Push was successfully sent\n- `t:error_response/0` - Push attempted but server responded\n  with error\n- `:timeout` - Internal error. Push did not reach ADM servers","ref":"Pigeon.ADM.Notification.html#t:response/0"},{"type":"type","title":"Pigeon.ADM.Notification.t/0","doc":"ADM notification","ref":"Pigeon.ADM.Notification.html#t:t/0"},{"type":"type","title":"Examples - Pigeon.ADM.Notification.t/0","doc":"%Pigeon.ADM.Notification{\n      consolidation_key: nil,\n      expires_after: 604_800,\n      md5: \"qzF+HgArKZjJrpfcTbiFxg==\",\n      payload: %{\n        \"data\" => %{\"message\" => \"your message\"}\n      },\n      registration_id: \"reg ID\",\n      response: nil, # Set on push response\n      updated_registration_id: nil\n    }","ref":"Pigeon.ADM.Notification.html#t:t/0-examples"},{"type":"module","title":"Pigeon.APNS","doc":"`Pigeon.Adapter` for Apple Push Notification Service (APNS) push notifications.","ref":"Pigeon.APNS.html"},{"type":"module","title":"Getting Started - Pigeon.APNS","doc":"1. Create an `APNS` dispatcher.\n\n```\n# lib/apns.ex\ndefmodule YourApp.APNS do\n  use Pigeon.Dispatcher, otp_app: :your_app\nend\n```\n\n2. (Optional) Add configuration to your `config.exs`.\n\n```\n# config.exs\n\nconfig :your_app, YourApp.APNS,\n  adapter: Pigeon.APNS,\n  cert: File.read!(\"cert.pem\"),\n  key: File.read!(\"key_unencrypted.pem\"),\n  mode: :dev\n```\n\nOr use token based authentication:\n\n```\nconfig :your_app, YourApp.APNS,\n  adapter: Pigeon.APNS,\n  key: File.read!(\"AuthKey.p8\"),\n  key_identifier: \"ABC1234567\",\n  mode: :dev,\n  team_id: \"DEF8901234\"\n```\n\n3. Start your dispatcher on application boot.\n\n```\ndefmodule YourApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @doc false\n  def start(_type, _args) do\n    children = [\n      YourApp.APNS\n    ]\n    opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nIf you skipped step two, include your configuration.\n\n```\ndefmodule YourApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @doc false\n  def start(_type, _args) do\n    children = [\n      {YourApp.APNS, apns_opts()}\n    ]\n    opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n\n  defp apns_opts do\n    [\n      adapter: Pigeon.APNS,\n      cert: File.read!(\"cert.pem\"),\n      key: File.read!(\"key_unencrypted.pem\"),\n      mode: :dev\n    ]\n  end\nend\n```\n\n4. Create a notification. **Note: Your push topic is generally the app's bundle identifier.**\n\n```\nn = Pigeon.APNS.Notification.new(\"your message\", \"your device token\", \"your push topic\")\n```\n \n5. Send the packet. Pushes are synchronous and return the notification with an\n updated `:response` key.\n\n```\nYourApp.APNS.push(n)\n```","ref":"Pigeon.APNS.html#module-getting-started"},{"type":"module","title":"Configuration Options - Pigeon.APNS","doc":"##","ref":"Pigeon.APNS.html#module-configuration-options"},{"type":"module","title":"Certificate Authentication - Pigeon.APNS","doc":"- `:cert` - Push certificate. Must be the full-text string of the file contents.\n- `:key` - Push private key. Must be the full-text string of the file contents.\n\n##","ref":"Pigeon.APNS.html#module-certificate-authentication"},{"type":"module","title":"Token Authentication - Pigeon.APNS","doc":"- `:key` - JWT private key. Must be the full-text string of the file contents.\n- `:key_identifier` - A 10-character key identifier (kid) key, obtained from\n  your developer account.\n- `:team_id` - Your 10-character Team ID, obtained from your developer account.\n\n##","ref":"Pigeon.APNS.html#module-token-authentication"},{"type":"module","title":"Shared Options - Pigeon.APNS","doc":"- `:mode` - If set to `:dev` or `:prod`, will set the appropriate `:uri`.\n- `:ping_period` - Interval between server pings. Necessary to keep long\n  running APNS connections alive. Defaults to 10 minutes.\n- `:port` - Push server port. Can be any value, but APNS only accepts\n  `443` and `2197`.\n- `:uri` - Push server uri. If set, overrides uri defined by `:mode`.\n  Useful for test environments.","ref":"Pigeon.APNS.html#module-shared-options"},{"type":"module","title":"Generating Your Certificate and Key .pem - Pigeon.APNS","doc":"1. In Keychain Access, right-click your push certificate and select _\"Export...\"_\n2. Export the certificate as `cert.p12`\n3. Click the dropdown arrow next to the certificate, right-click the private\n   key and select _\"Export...\"_\n4. Export the private key as `key.p12`\n5. From a shell, convert the certificate.\n\n```\nopenssl pkcs12 -legacy -clcerts -nokeys -out cert.pem -in cert.p12\n```\n\n6. Convert the key. Be sure to set a PEM pass phrase here. The pass phrase must be 4 or \n   more characters in length or this will not work. You will need that pass phrase added \n   here in order to remove it in the next step.\n\n```\nopenssl pkcs12 -legacy -nocerts -out key.pem -in key.p12\n```\n\n7. Remove the PEM pass phrase from the key.\n\n```\nopenssl rsa -in key.pem -out key_unencrypted.pem\n```\n\n8. `cert.pem` and `key_unencrypted.pem` can now be used in your configuration.","ref":"Pigeon.APNS.html#module-generating-your-certificate-and-key-pem"},{"type":"module","title":"Pigeon.APNS.Notification","doc":"Defines APNS notification struct and constructor functions.","ref":"Pigeon.APNS.Notification.html"},{"type":"function","title":"Pigeon.APNS.Notification.new/3","doc":"Returns an `APNS.Notification` struct with given message, device token, and\ntopic (optional).\n\nPush payload is constructed in the form of `%{\"aps\" => %{\"alert\" => msg}}`","ref":"Pigeon.APNS.Notification.html#new/3"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.new/3","doc":"iex> Pigeon.APNS.Notification.new(\"push message\", \"device token\")\n    %Pigeon.APNS.Notification{\n      __meta__: %Pigeon.Metadata{},\n      device_token: \"device token\",\n      expiration: nil,\n      priority: nil,\n      push_type: \"alert\",\n      id: nil,\n      payload: %{\"aps\" => %{\"alert\" => \"push message\"}},\n      topic: nil\n    }","ref":"Pigeon.APNS.Notification.html#new/3-examples"},{"type":"function","title":"Pigeon.APNS.Notification.new/4","doc":"Returns an `APNS.Notification` struct with given message, device token,\ntopic, and message ID.\n\nPush payload is constructed in the form of `%{\"aps\" => %{\"alert\" => msg}}`","ref":"Pigeon.APNS.Notification.html#new/4"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.new/4","doc":"iex> Pigeon.APNS.Notification.new(\"push message\", \"device token\", \"topic\", \"id_1234\")\n    %Pigeon.APNS.Notification{\n      collapse_id: nil,\n      device_token: \"device token\",\n      expiration: nil,\n      priority: nil,\n      push_type: \"alert\",\n      id: \"id_1234\",\n      payload: %{\"aps\" => %{\"alert\" => \"push message\"}},\n      topic: \"topic\"\n    }","ref":"Pigeon.APNS.Notification.html#new/4-examples"},{"type":"function","title":"Pigeon.APNS.Notification.put_alert/2","doc":"Updates `\"alert\"` key in push payload.\n\nThis is the alert message displayed on the device.","ref":"Pigeon.APNS.Notification.html#put_alert/2"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.put_alert/2","doc":"iex> Pigeon.APNS.Notification.put_alert(%Pigeon.APNS.Notification{}, \"push message\")\n    %Pigeon.APNS.Notification{\n      payload: %{\"aps\" => %{\"alert\" => \"push message\"}}\n    }","ref":"Pigeon.APNS.Notification.html#put_alert/2-examples"},{"type":"function","title":"Pigeon.APNS.Notification.put_badge/2","doc":"Updates `\"badge\"` key in push payload.\n\nThis is the badge number displayed on the application.","ref":"Pigeon.APNS.Notification.html#put_badge/2"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.put_badge/2","doc":"iex> Pigeon.APNS.Notification.put_badge(%Pigeon.APNS.Notification{}, 5)\n    %Pigeon.APNS.Notification{\n      payload: %{\"aps\" => %{\"badge\" => 5}}\n    }","ref":"Pigeon.APNS.Notification.html#put_badge/2-examples"},{"type":"function","title":"Pigeon.APNS.Notification.put_category/2","doc":"Updates `\"category\"` key in push payload.","ref":"Pigeon.APNS.Notification.html#put_category/2"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.put_category/2","doc":"iex> Pigeon.APNS.Notification.put_category(%Pigeon.APNS.Notification{}, \"category\")\n    %Pigeon.APNS.Notification{\n      payload: %{\"aps\" => %{\"category\" => \"category\"}}\n    }","ref":"Pigeon.APNS.Notification.html#put_category/2-examples"},{"type":"function","title":"Pigeon.APNS.Notification.put_content_available/1","doc":"Sets `\"content-available\"` flag in push payload.\n\nUsed for silent notifications. When set, ensure `alert`, `badge`, and `sound` keys\nare not configured.","ref":"Pigeon.APNS.Notification.html#put_content_available/1"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.put_content_available/1","doc":"iex> Pigeon.APNS.Notification.put_content_available(%Pigeon.APNS.Notification{})\n    %Pigeon.APNS.Notification{\n      payload: %{\"aps\" => %{\"content-available\" => 1}}\n    }","ref":"Pigeon.APNS.Notification.html#put_content_available/1-examples"},{"type":"function","title":"Pigeon.APNS.Notification.put_custom/2","doc":"Puts custom data in push payload.","ref":"Pigeon.APNS.Notification.html#put_custom/2"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.put_custom/2","doc":"iex> n = Pigeon.APNS.Notification.new(\"test message\", \"device token\")\n    iex> Pigeon.APNS.Notification.put_custom(n, %{\"custom-key\" => 1234})\n    %Pigeon.APNS.Notification{\n      device_token: \"device token\",\n      payload: %{\"aps\" => %{\"alert\" => \"test message\"}, \"custom-key\" => 1234}\n    }","ref":"Pigeon.APNS.Notification.html#put_custom/2-examples"},{"type":"function","title":"Pigeon.APNS.Notification.put_interruption_level/2","doc":"Updates `\"interruption-level\"` key in push payload.\n\nUsed for managing time sensitive notifications","ref":"Pigeon.APNS.Notification.html#put_interruption_level/2"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.put_interruption_level/2","doc":"iex> Pigeon.APNS.Notification.put_interruption_level(%Pigeon.APNS.Notification{}, \"time-sensitive\")\n    %Pigeon.APNS.Notification{\n      payload: %{\"aps\" => %{\"interruption-level\" => \"time-sensitive\"}}\n    }","ref":"Pigeon.APNS.Notification.html#put_interruption_level/2-examples"},{"type":"function","title":"Pigeon.APNS.Notification.put_mutable_content/1","doc":"Sets `\"mutable-content\"` flag in push payload.\n\nUsed for notification service extensions (such as displaying custom media).","ref":"Pigeon.APNS.Notification.html#put_mutable_content/1"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.put_mutable_content/1","doc":"iex> Pigeon.APNS.Notification.put_mutable_content(%Pigeon.APNS.Notification{})\n    %Pigeon.APNS.Notification{\n      payload: %{\"aps\" => %{\"mutable-content\" => 1}}\n    }","ref":"Pigeon.APNS.Notification.html#put_mutable_content/1-examples"},{"type":"function","title":"Pigeon.APNS.Notification.put_sound/2","doc":"Updates `\"sound\"` key in push payload.\n\nUsed for custom notification sounds. Value should\nbe the name of the custom sound file in the application's binary.","ref":"Pigeon.APNS.Notification.html#put_sound/2"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.put_sound/2","doc":"iex> Pigeon.APNS.Notification.put_sound(%Pigeon.APNS.Notification{}, \"custom.aiff\")\n    %Pigeon.APNS.Notification{\n      payload: %{\"aps\" => %{\"sound\" => \"custom.aiff\"}}\n    }\n\n    iex> Pigeon.APNS.Notification.put_sound(%Pigeon.APNS.Notification{}, %{\n    ...>   \"critical\" => 1,\n    ...>   \"sound\" => \"default\",\n    ...>   \"volume\" => 1.0\n    ...> })\n    %Pigeon.APNS.Notification{\n      payload: %{\n        \"aps\" => %{\n          \"sound\" => %{\n            \"critical\" => 1,\n            \"sound\" => \"default\",\n            \"volume\" => 1.0\n          }\n        }\n      }\n    }","ref":"Pigeon.APNS.Notification.html#put_sound/2-examples"},{"type":"function","title":"Pigeon.APNS.Notification.put_target_content_id/2","doc":"Updates `\"target-content-id\"` key in push payload.\n\nUsed for bringing a specific window forward.","ref":"Pigeon.APNS.Notification.html#put_target_content_id/2"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.put_target_content_id/2","doc":"iex> Pigeon.APNS.Notification.put_target_content_id(%Pigeon.APNS.Notification{}, \"example\")\n    %Pigeon.APNS.Notification{\n      payload: %{\"aps\" => %{\"target-content-id\" => \"example\"}}\n    }","ref":"Pigeon.APNS.Notification.html#put_target_content_id/2-examples"},{"type":"function","title":"Pigeon.APNS.Notification.put_thread_id/2","doc":"Updates `\"thread-id\"` key in push payload.\n\nUsed for grouping related notifications.","ref":"Pigeon.APNS.Notification.html#put_thread_id/2"},{"type":"function","title":"Examples - Pigeon.APNS.Notification.put_thread_id/2","doc":"iex> Pigeon.APNS.Notification.put_thread_id(%Pigeon.APNS.Notification{}, \"example\")\n    %Pigeon.APNS.Notification{\n      payload: %{\"aps\" => %{\"thread-id\" => \"example\"}}\n    }","ref":"Pigeon.APNS.Notification.html#put_thread_id/2-examples"},{"type":"type","title":"Pigeon.APNS.Notification.error_response/0","doc":"","ref":"Pigeon.APNS.Notification.html#t:error_response/0"},{"type":"type","title":"Pigeon.APNS.Notification.response/0","doc":"APNS push response\n\n- nil - Push has not been sent yet.\n- `:success` - Push was successfully sent.\n- `t:Pigeon.APNS.Error.error_response/0` - Push attempted but\n   server responded with error.\n- `:timeout` - Internal error. Push did not reach APNS servers.","ref":"Pigeon.APNS.Notification.html#t:response/0"},{"type":"type","title":"Pigeon.APNS.Notification.t/0","doc":"APNS notification","ref":"Pigeon.APNS.Notification.html#t:t/0"},{"type":"type","title":"Examples - Pigeon.APNS.Notification.t/0","doc":"%Pigeon.APNS.Notification{\n        __meta__: %Pigeon.Metadata{on_response: nil},\n        collapse_id: nil,\n        device_token: \"device token\",\n        expiration: nil,\n        id: nil, # Set on push response if nil\n        payload: %{\"aps\" => %{\"alert\" => \"push message\"}},\n        priority: nil,\n        push_type: \"alert\",\n        response: nil, # Set on push response\n        topic: \"com.example.YourApp\"\n    }","ref":"Pigeon.APNS.Notification.html#t:t/0-examples"},{"type":"module","title":"Pigeon.FCM","doc":"`Pigeon.Adapter` for Firebase Cloud Messaging (FCM) push notifications.","ref":"Pigeon.FCM.html"},{"type":"module","title":"Getting Started - Pigeon.FCM","doc":"1. Create a `FCM` dispatcher.\n\n```\n# lib/fcm.ex\ndefmodule YourApp.FCM do\n  use Pigeon.Dispatcher, otp_app: :your_app\nend\n```\n\n2. (Optional) Add configuration to your `config.exs`.\n\n```\n# config.exs\n\nconfig :your_app, YourApp.FCM,\n  adapter: Pigeon.FCM,\n  project_id: \"example-project-123\",\n  service_account_json: File.read!(\"service-account.json\")\n```\n\n3. Start your dispatcher on application boot.\n\n```\ndefmodule YourApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @doc false\n  def start(_type, _args) do\n    children = [\n      YourApp.FCM\n    ]\n    opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nIf you skipped step two, include your configuration.\n\n```\ndefmodule YourApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @doc false\n  def start(_type, _args) do\n    children = [\n      {YourApp.FCM, fcm_opts()}\n    ]\n    opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n\n  defp fcm_opts do\n    [\n      adapter: Pigeon.FCM,\n      project_id: \"example-project-123\",\n      service_account_json: File.read!(\"service-account.json\")\n    ]\n  end\nend\n```\n\n4. Create a notification.\n\n```\nn = Pigeon.FCM.Notification.new({:token, \"reg ID\"}, %{\"body\" => \"test message\"})\n```\n \n5. Send the notification. \n\nOn successful response, `:name` will be set to the name returned from the FCM \nAPI and `:response` will be `:success`. If there was an error, `:error` will \ncontain a JSON map of the response and `:response` will be an atomized version\nof the error type.\n\n```\nYourApp.FCM.push(n)\n```","ref":"Pigeon.FCM.html#module-getting-started"},{"type":"module","title":"Pigeon.FCM.Notification","doc":"Defines FCM notification struct and convenience constructor functions.","ref":"Pigeon.FCM.Notification.html"},{"type":"function","title":"Pigeon.FCM.Notification.new/3","doc":"Creates `FCM.Notification` struct with given target and optional\nnotification and data payloads.","ref":"Pigeon.FCM.Notification.html#new/3"},{"type":"function","title":"Examples - Pigeon.FCM.Notification.new/3","doc":"iex> Pigeon.FCM.Notification.new({:token, \"reg ID\"})\n    %Pigeon.FCM.Notification{\n      data: nil,\n      notification: nil,\n      target: {:token, \"reg ID\"}\n    }\n\n    iex> Pigeon.FCM.Notification.new({:topic, \"example\"})\n    %Pigeon.FCM.Notification{\n      data: nil,\n      notification: nil,\n      target: {:topic, \"example\"}\n    }\n\n    iex> Pigeon.FCM.Notification.new({:token, \"reg ID\"}, %{\"body\" => \"test message\"})\n    %Pigeon.FCM.Notification{\n      data: nil,\n      notification: %{\"body\" => \"test message\"},\n      target: {:token, \"reg ID\"}\n    }\n\n    iex> Pigeon.FCM.Notification.new({:token, \"reg ID\"}, %{\"body\" => \"test message\"},\n    ...> %{\"key\" => \"value\"})\n    %Pigeon.FCM.Notification{\n      data: %{\"key\" => \"value\"},\n      notification: %{\"body\" => \"test message\"},\n      target: {:token, \"reg ID\"}\n    }","ref":"Pigeon.FCM.Notification.html#new/3-examples"},{"type":"type","title":"Pigeon.FCM.Notification.error_response/0","doc":"","ref":"Pigeon.FCM.Notification.html#t:error_response/0"},{"type":"type","title":"Pigeon.FCM.Notification.t/0","doc":"","ref":"Pigeon.FCM.Notification.html#t:t/0"},{"type":"type","title":"Pigeon.FCM.Notification.target/0","doc":"FCM notification target. Must be one of the following:\n\n- `{:token, \"string\"}` - Registration token to send a message to.\n- `{:topic, \"string\"}` - Topic name to send a message to, e.g. \"weather\". \n  Note: \"/topics/\" prefix should not be provided.\n- `{:condition, \"string\"}` - Condition to send a message to, e.g. \"'foo' \n  in topics && 'bar' in topics\".","ref":"Pigeon.FCM.Notification.html#t:target/0"},{"type":"module","title":"Pigeon.LegacyFCM","doc":"`Pigeon.Adapter` for Legacy Firebase Cloud Messaging (FCM) push notifications.","ref":"Pigeon.LegacyFCM.html"},{"type":"module","title":"Getting Started - Pigeon.LegacyFCM","doc":"1. Create a `LegacyFCM` dispatcher.\n\n```\n# lib/legacy_fcm.ex\ndefmodule YourApp.LegacyFCM do\n  use Pigeon.Dispatcher, otp_app: :your_app\nend\n```\n\n2. (Optional) Add configuration to your `config.exs`.\n\n```\n# config.exs\n\nconfig :your_app, YourApp.LegacyFCM,\n  adapter: Pigeon.LegacyFCM,\n  key: \"your_fcm_key_here\"\n```\n\n3. Start your dispatcher on application boot.\n\n```\ndefmodule YourApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @doc false\n  def start(_type, _args) do\n    children = [\n      YourApp.LegacyFCM\n    ]\n    opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nIf you skipped step two, include your configuration.\n\n```\ndefmodule YourApp.Application do\n  @moduledoc false\n\n  use Application\n\n  @doc false\n  def start(_type, _args) do\n    children = [\n      {YourApp.ADM, legacy_fcm_opts()}\n    ]\n    opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n\n  defp legacy_fcm_opts do\n    [\n      adapter: Pigeon.LegacyFCM, \n      key: \"your_fcm_key_here\"\n    ]\n  end\nend\n```\n\n4. Create a notification.\n\n```\nmsg = %{\"body\" => \"your message\"}\nn = Pigeon.LegacyFCM.Notification.new(\"your device registration ID\", msg)\n```\n \n5. Send the notification. \n\nPushes are synchronous and return the notification with\nupdated `:status` and `:response` keys. If `:status` is success, `:response`\nwill contain a keyword list of individual registration ID responses.\n\n```\nYourApp.LegacyFCM.push(n)\n```","ref":"Pigeon.LegacyFCM.html#module-getting-started"},{"type":"module","title":"Sending to Multiple Registration IDs - Pigeon.LegacyFCM","doc":"Pass in a list of registration IDs, as many as you want.\n\n```\nmsg = %{\"body\" => \"your message\"}\nn = Pigeon.FCM.Notification.new([\"first ID\", \"second ID\"], msg)\n```","ref":"Pigeon.LegacyFCM.html#module-sending-to-multiple-registration-ids"},{"type":"module","title":"Notification Struct - Pigeon.LegacyFCM","doc":"```\n%Pigeon.LegacyFCM.Notification{\n  collapse_key: nil | String.t(),\n  dry_run: boolean,\n  message_id: nil | String.t(),\n  payload: %{...},\n  priority: :normal | :high,\n  registration_id: String.t() | [String.t(), ...],\n  response: [] | [{atom, String.t()}, ...], | atom,\n  restricted_package_name: nil | String.t(),\n  status: atom | nil,\n  time_to_live: non_neg_integer\n}\n```","ref":"Pigeon.LegacyFCM.html#module-notification-struct"},{"type":"module","title":"Notifications with Custom Data - Pigeon.LegacyFCM","doc":"FCM accepts both `notification` and `data` keys in its JSON payload. Set them like so:\n\n```\nnotification = %{\"body\" => \"your message\"}\ndata = %{\"key\" => \"value\"}\nPigeon.LegacyFCM.Notification.new(\"registration ID\", notification, data)\n```\n\nor\n\n```\nPigeon.LegacyFCM.Notification.new(\"registration ID\")\n|> put_notification(%{\"body\" => \"your message\"})\n|> put_data(%{\"key\" => \"value\"})\n```","ref":"Pigeon.LegacyFCM.html#module-notifications-with-custom-data"},{"type":"module","title":"Handling Push Responses - Pigeon.LegacyFCM","doc":"1. Pass an optional anonymous function as your second parameter.\n\n```\ndata = %{message: \"your message\"}\nn = Pigeon.FCM.Notification.new(data, \"device registration ID\")\nPigeon.FCM.push(n, fn(x) -> IO.inspect(x) end)\n{:ok, %Pigeon.FCM.Notification{...}}\n```\n\n2. Responses return the notification with an updated response.\n\n```\non_response = fn(n) ->\n  case n.status do\n    :success ->\n      bad_regids = FCM.Notification.remove?(n)\n      to_retry = FCM.Notification.retry?(n)\n      # Handle updated regids, remove bad ones, etc\n    :unauthorized ->\n      # Bad FCM key\n    error ->\n      # Some other error\n  end\nend\n\ndata = %{message: \"your message\"}\nn = Pigeon.FCM.Notification.new(\"your device token\", data)\nPigeon.FCM.push(n, on_response: on_response)\n```","ref":"Pigeon.LegacyFCM.html#module-handling-push-responses"},{"type":"module","title":"Error Responses - Pigeon.LegacyFCM","doc":"*Slightly modified from [FCM Server Reference](https://firebase.google.com/docs/cloud-messaging/http-server-ref#error-codes)*\n\n| Reason                           | Description                  |\n|----------------------------------|------------------------------|\n| `:missing_registration`          | Missing Registration Token   |\n| `:invalid_registration`          | Invalid Registration Token   |\n| `:not_registered`                | Unregistered Device          |\n| `:invalid_package_name`          | Invalid Package Name         |\n| `:authentication_error`          | Authentication Error         |\n| `:mismatch_sender_id`            | Mismatched Sender            |\n| `:invalid_json`                  | Invalid JSON                 |\n| `:message_too_big`               | Message Too Big              |\n| `:invalid_data_key`              | Invalid Data Key             |\n| `:invalid_ttl`                   | Invalid Time to Live         |\n| `:unavailable`                   | Timeout                      |\n| `:internal_server_error`         | Internal Server Error        |\n| `:device_message_rate_exceeded`  | Message Rate Exceeded        |\n| `:topics_message_rate_exceeded`  | Topics Message Rate Exceeded |\n| `:unknown_error`                 | Unknown Error                |","ref":"Pigeon.LegacyFCM.html#module-error-responses"},{"type":"module","title":"Pigeon.LegacyFCM.Notification","doc":"Defines `Pigeon.LegacyFCM.Notification` struct and convenience constructor functions.","ref":"Pigeon.LegacyFCM.Notification.html"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.new/3","doc":"Creates `LegacyFCM.Notification` struct with device registration IDs and optional\nnotification and data payloads.","ref":"Pigeon.LegacyFCM.Notification.html#new/3"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.new/3","doc":"iex> Pigeon.LegacyFCM.Notification.new(\"reg ID\")\n    %Pigeon.LegacyFCM.Notification{\n      payload: %{},\n      registration_id: \"reg ID\",\n      priority: :normal\n    }\n\n    iex> Pigeon.LegacyFCM.Notification.new(\"reg ID\", %{\"body\" => \"test message\"})\n    %Pigeon.LegacyFCM.Notification{\n      payload: %{\"notification\" => %{\"body\" => \"test message\"}},\n      registration_id: \"reg ID\",\n      priority: :normal\n    }\n\n    iex> Pigeon.LegacyFCM.Notification.new(\"reg ID\", %{\"body\" => \"test message\"},\n    ...> %{\"key\" => \"value\"})\n    %Pigeon.LegacyFCM.Notification{\n      payload: %{\n        \"data\" => %{\"key\" => \"value\"},\n        \"notification\" => %{\"body\" => \"test message\"}\n      },\n      registration_id: \"reg ID\",\n      priority: :normal\n    }\n\n    iex> regids = Enum.map(0..1_499, fn(_x) -> \"reg ID\" end)\n    iex> [n1 | [n2]] = Pigeon.LegacyFCM.Notification.new(regids,\n    ...> %{\"body\" => \"test message\"}, %{\"key\" => \"value\"})\n    iex> Enum.count(n1.registration_id)\n    1000\n    iex> Enum.count(n2.registration_id)\n    500","ref":"Pigeon.LegacyFCM.Notification.html#new/3-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_collapse_key/2","doc":"Updates `\"collapse_key\"` key.","ref":"Pigeon.LegacyFCM.Notification.html#put_collapse_key/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_collapse_key/2","doc":"iex> put_collapse_key(%Pigeon.LegacyFCM.Notification{}, \"Updates available\")\n    %Pigeon.LegacyFCM.Notification{collapse_key: \"Updates available\"}","ref":"Pigeon.LegacyFCM.Notification.html#put_collapse_key/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_condition/2","doc":"Updates `\"condition\"` key.\n\nSupported condition: Topic, formatted as \"'yourTopic' in topics\". This value\nis case-insensitive.\n\nSupported operators: &&, ||. Maximum two operators per topic message supported.","ref":"Pigeon.LegacyFCM.Notification.html#put_condition/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_condition/2","doc":"iex> put_condition(%Pigeon.LegacyFCM.Notification{}, \"'test' in topics\")\n    %Pigeon.LegacyFCM.Notification{condition: \"'test' in topics\"}","ref":"Pigeon.LegacyFCM.Notification.html#put_condition/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_content_available/2","doc":"Updates `\"content_available\"` key.\n\nOn iOS, use this field to represent content-available in the APNs payload.\nWhen a notification or message is sent and this is set to true, an inactive\nclient app is awoken, and the message is sent through APNs as a silent\nnotification and not through the FCM connection server. Note that silent\nnotifications in APNs are not guaranteed to be delivered, and can depend on\nfactors such as the user turning on Low Power Mode, force quitting the app,\netc. On Android, data messages wake the app by default. On Chrome, currently\nnot supported.","ref":"Pigeon.LegacyFCM.Notification.html#put_content_available/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_content_available/2","doc":"iex> put_content_available(%Pigeon.LegacyFCM.Notification{}, true)\n    %Pigeon.LegacyFCM.Notification{content_available: true}","ref":"Pigeon.LegacyFCM.Notification.html#put_content_available/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_data/2","doc":"Updates `\"data\"` key in push payload.\n\nThis parameter specifies the custom key-value pairs of the message's payload.\n\nFor example, with data:{\"score\":\"3x1\"}:\n\nOn iOS, if the message is sent via APNs, it represents the custom data fields.\nIf it is sent via FCM connection server, it would be represented as key value\ndictionary in AppDelegate application:didReceiveRemoteNotification:.\n\nOn Android, this would result in an intent extra named score with the string\nvalue 3x1.\n\nThe key should not be a reserved word (\"from\" or any word starting with\n\"google\" or \"gcm\"). Do not use any of the words defined in this table\n(such as collapse_key).\n\nValues in string types are recommended. You have to convert values in objects\nor other non-string data types (e.g., integers or booleans) to string.","ref":"Pigeon.LegacyFCM.Notification.html#put_data/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_data/2","doc":"iex> put_data(%Pigeon.LegacyFCM.Notification{}, %{\"key\" => 1234})\n    %Pigeon.LegacyFCM.Notification{\n      payload: %{\"data\" => %{\"key\" => 1234}},\n      registration_id: nil\n    }","ref":"Pigeon.LegacyFCM.Notification.html#put_data/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_dry_run/1","doc":"Sets `\"dry_run\"` key to true.\n\nThis parameter, when set to true, allows developers to test a request without\nactually sending a message.\n\nThe default value is false.","ref":"Pigeon.LegacyFCM.Notification.html#put_dry_run/1"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_dry_run/1","doc":"iex> put_dry_run(%Pigeon.LegacyFCM.Notification{})\n    %Pigeon.LegacyFCM.Notification{dry_run: true}","ref":"Pigeon.LegacyFCM.Notification.html#put_dry_run/1-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_mutable_content/2","doc":"Updates `\"mutable_content\"` key.\n\nCurrently for iOS 10+ devices only. On iOS, use this field to represent\nmutable-content in the APNs payload. When a notification is sent and this is\nset to true, the content of the notification can be modified before it is\ndisplayed, using a Notification Service app extension. This parameter will be\nignored for Android and web.","ref":"Pigeon.LegacyFCM.Notification.html#put_mutable_content/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_mutable_content/2","doc":"iex> put_mutable_content(%Pigeon.LegacyFCM.Notification{}, true)\n    %Pigeon.LegacyFCM.Notification{mutable_content: true}","ref":"Pigeon.LegacyFCM.Notification.html#put_mutable_content/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_notification/2","doc":"Updates `\"notification\"` key in push payload.\n\nThis parameter specifies the predefined, user-visible key-value pairs of the\nnotification payload. See Notification payload support for detail. For more\ninformation about notification message and data message options, see\n[Message types](https://firebase.google.com/docs/cloud-messaging/concept-options#notifications_and_data_messages).\nIf a notification payload is provided, or the content_available option is set\nto true for a message to an iOS device, the message is sent through APNs,\notherwise it is sent through the FCM connection server.","ref":"Pigeon.LegacyFCM.Notification.html#put_notification/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_notification/2","doc":"iex> put_notification(%Pigeon.LegacyFCM.Notification{},\n    ...> %{\"body\" => \"message\"})\n    %Pigeon.LegacyFCM.Notification{\n      payload: %{\"notification\" => %{\"body\" => \"message\"}},\n      registration_id: nil\n    }","ref":"Pigeon.LegacyFCM.Notification.html#put_notification/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_priority/2","doc":"Updates `\"priority\"` key.\n\nSets the priority of the message. Valid values are \"normal\" and \"high.\" On\niOS, these correspond to APNs priorities 5 and 10.\n\nBy default, notification messages are sent with high priority, and data\nmessages are sent with normal priority. Normal priority optimizes the client\napp's battery consumption and should be used unless immediate delivery is\nrequired. For messages with normal priority, the app may receive the message\nwith unspecified delay.\n\nWhen a message is sent with high priority, it is sent immediately, and the app\ncan display a notification.","ref":"Pigeon.LegacyFCM.Notification.html#put_priority/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_priority/2","doc":"iex> put_priority(%Pigeon.LegacyFCM.Notification{}, :normal)\n    %Pigeon.LegacyFCM.Notification{priority: :normal}\n\n    iex> put_priority(%Pigeon.LegacyFCM.Notification{}, :high)\n    %Pigeon.LegacyFCM.Notification{priority: :high}\n\n    iex> put_priority(%Pigeon.LegacyFCM.Notification{priority: :normal}, :bad)\n    %Pigeon.LegacyFCM.Notification{priority: :normal}","ref":"Pigeon.LegacyFCM.Notification.html#put_priority/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_restricted_package_name/2","doc":"Updates `\"restricted_package_name\"` key.\n\nThis parameter specifies the package name of the application where the\nregistration tokens must match in order to receive the message. (Only affects android)","ref":"Pigeon.LegacyFCM.Notification.html#put_restricted_package_name/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_restricted_package_name/2","doc":"iex> put_restricted_package_name(%Pigeon.LegacyFCM.Notification{}, \"com.example.app\")\n    %Pigeon.LegacyFCM.Notification{restricted_package_name: \"com.example.app\"}","ref":"Pigeon.LegacyFCM.Notification.html#put_restricted_package_name/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.put_time_to_live/2","doc":"Updates `\"time_to_live\"` key.\n\nThis parameter specifies how long (in seconds) the message should be kept in\nFCM storage if the device is offline. The maximum time to live supported is 4\nweeks, and the default value is 4 weeks. For more information, see\n[Setting the lifespan of a message](https://firebase.google.com/docs/cloud-messaging/concept-options#ttl).","ref":"Pigeon.LegacyFCM.Notification.html#put_time_to_live/2"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.put_time_to_live/2","doc":"iex> put_time_to_live(%Pigeon.LegacyFCM.Notification{}, 60 * 60 * 24)\n    %Pigeon.LegacyFCM.Notification{time_to_live: 86_400}","ref":"Pigeon.LegacyFCM.Notification.html#put_time_to_live/2-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.remove?/1","doc":"Returns a list of registration IDs that should be removed","ref":"Pigeon.LegacyFCM.Notification.html#remove?/1"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.remove?/1","doc":"iex> n = %Pigeon.LegacyFCM.Notification{response: [\n    ...> {:success, \"regid1\"}, {:invalid_registration, \"regid2\"},\n    ...> {:success, \"regid3\"}, {:update, {\"regid4\", \"new_regid4\"}},\n    ...> {:not_registered, \"regid5\"}, {:unavailable, \"regid6\"}]}\n    iex> remove?(n)\n    [\"regid2\", \"regid5\"]","ref":"Pigeon.LegacyFCM.Notification.html#remove?/1-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.retry?/1","doc":"Returns a list of registration IDs that should be retried","ref":"Pigeon.LegacyFCM.Notification.html#retry?/1"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.retry?/1","doc":"iex> n = %Pigeon.LegacyFCM.Notification{response: [\n    ...> {:success, \"regid1\"}, {:invalid_registration, \"regid2\"},\n    ...> {:success, \"regid3\"}, {:update, {\"regid4\", \"new_regid4\"}},\n    ...> {:not_registered, \"regid5\"}, {:unavailable, \"regid6\"}]}\n    iex> retry?(n)\n    [\"regid6\"]","ref":"Pigeon.LegacyFCM.Notification.html#retry?/1-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.success?/1","doc":"Returns a list of successful registration IDs","ref":"Pigeon.LegacyFCM.Notification.html#success?/1"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.success?/1","doc":"iex> n = %Pigeon.LegacyFCM.Notification{response: [\n    ...> {:success, \"regid1\"}, {:invalid_registration, \"regid2\"},\n    ...> {:success, \"regid3\"}, {:update, {\"regid4\", \"new_regid4\"}},\n    ...> {:not_registered, \"regid5\"}, {:unavailable, \"regid6\"}]}\n    iex> success?(n)\n    [\"regid1\", \"regid3\"]","ref":"Pigeon.LegacyFCM.Notification.html#success?/1-examples"},{"type":"function","title":"Pigeon.LegacyFCM.Notification.update?/1","doc":"Returns a list of registration IDs and their corresponding new ID","ref":"Pigeon.LegacyFCM.Notification.html#update?/1"},{"type":"function","title":"Examples - Pigeon.LegacyFCM.Notification.update?/1","doc":"iex> n = %Pigeon.LegacyFCM.Notification{response: [\n    ...> {:success, \"regid1\"}, {:invalid_registration, \"regid2\"},\n    ...> {:success, \"regid3\"}, {:update, {\"regid4\", \"new_regid4\"}},\n    ...> {:not_registered, \"regid5\"}, {:unavailable, \"regid6\"}]}\n    iex> update?(n)\n    [{\"regid4\", \"new_regid4\"}]","ref":"Pigeon.LegacyFCM.Notification.html#update?/1-examples"},{"type":"type","title":"Pigeon.LegacyFCM.Notification.regid_error_response/0","doc":"","ref":"Pigeon.LegacyFCM.Notification.html#t:regid_error_response/0"},{"type":"type","title":"Pigeon.LegacyFCM.Notification.regid_response/0","doc":"LegacyFCM push response for individual registration IDs\n\n- `{:success, \"reg_id\"}` - Push was successfully sent\n- `{:update, {\"reg_id\", \"new_reg_id\"}}` - Push successful but user should\n  use new registration ID for future pushes\n- `{regid_error_response, \"reg_id\"}` - Push attempted but server responded\n  with error","ref":"Pigeon.LegacyFCM.Notification.html#t:regid_response/0"},{"type":"type","title":"Pigeon.LegacyFCM.Notification.status/0","doc":"Status of LegacyFCM request\n\n- `:success` - Notification was processed successfully\n- `:timeout` - Worker did not respond within timeout. This is likely an\n   internal error\n- `:unauthorized` - Bad LegacyFCM key\n- `:malformed_json` - Push payload was invalid JSON\n- `:internal_server_error` - LegacyFCM server encountered an error while trying\n   to process the request\n- `:unavailable` - LegacyFCM server couldn't process the request in time","ref":"Pigeon.LegacyFCM.Notification.html#t:status/0"},{"type":"type","title":"Pigeon.LegacyFCM.Notification.t/0","doc":"","ref":"Pigeon.LegacyFCM.Notification.html#t:t/0"},{"type":"exception","title":"Pigeon.ConfigError","doc":"","ref":"Pigeon.ConfigError.html"}],"content_type":"text/markdown"}